.g-url-container{margin-top:20px}.g-authorized-upload-page-wrapper{max-width:770px;margin:100px auto 0}.g-authorized-upload-page-wrapper p{font-size:16px}.g-authorized-upload-page-wrapper #g-authorized-upload-email{margin-bottom:15px}.g-authorized-upload-page-wrapper .g-upload-widget-container{margin-top:40px}.g-authorized-upload-page-wrapper .g-upload-widget-container .g-dialog-subtitle{display:none}.g-authorized-upload-page-wrapper .g-upload-widget-container .g-drop-zone{text-align:center;background-color:#5cb897;border:1px solid #4a8;width:100%;height:60px;padding:0;line-height:60px;box-shadow:0 2px 5px #0003}.g-authorized-upload-page-wrapper .g-upload-widget-container .g-drop-zone:hover{background:linear-gradient(#6cc8a7 50%,#5cb897 100%)}.g-authorized-upload-page-wrapper .g-upload-widget-container .g-drop-zone:active{background:#6cc8a7;box-shadow:inset 0 3px 5px #00000020}.g-authorized-upload-page-wrapper .g-upload-widget-container .g-drop-zone.g-dropzone-show{box-shadow:none;background:#fff;border:2px dashed #bbb;padding:0}.g-authorized-upload-page-wrapper .g-upload-widget-container button.g-start-upload{margin:0 auto;padding:10px 15px;font-size:18px}.g-authorized-upload-page-wrapper .g-complete-wrapper p{text-align:center;font-size:20px}
/*$vite$:1*/